@@ -59,20 +59,22 @@ sub get {
 
 sub _validators {
     return {
-        accepted   => 'Dancer2::Plugin::FormValidator::Validator::Accepted',
-        alpha      => 'Dancer2::Plugin::FormValidator::Validator::Alpha',
-        alpha_num  => 'Dancer2::Plugin::FormValidator::Validator::AlphaNum',
-        enum       => 'Dancer2::Plugin::FormValidator::Validator::Enum',
-        email      => 'Dancer2::Plugin::FormValidator::Validator::Email',
-        email_dns  => 'Dancer2::Plugin::FormValidator::Validator::EmailDns',
-        integer    => 'Dancer2::Plugin::FormValidator::Validator::Integer',
-        length_max => 'Dancer2::Plugin::FormValidator::Validator::LengthMax',
-        length_min => 'Dancer2::Plugin::FormValidator::Validator::LengthMin',
-        max        => 'Dancer2::Plugin::FormValidator::Validator::Max',
-        min        => 'Dancer2::Plugin::FormValidator::Validator::Min',
-        numeric    => 'Dancer2::Plugin::FormValidator::Validator::Numeric',
-        required   => 'Dancer2::Plugin::FormValidator::Validator::Required',
-        same       => 'Dancer2::Plugin::FormValidator::Validator::Same',
+        accepted        => 'Dancer2::Plugin::FormValidator::Validator::Accepted',
+        alpha           => 'Dancer2::Plugin::FormValidator::Validator::Alpha',
+        alpha_ascii     => 'Dancer2::Plugin::FormValidator::Validator::AlphaAscii',
+        alpha_num       => 'Dancer2::Plugin::FormValidator::Validator::AlphaNum',
+        alpha_num_ascii => 'Dancer2::Plugin::FormValidator::Validator::AlphaNumAscii',
+        enum            => 'Dancer2::Plugin::FormValidator::Validator::Enum',
+        email           => 'Dancer2::Plugin::FormValidator::Validator::Email',
+        email_dns       => 'Dancer2::Plugin::FormValidator::Validator::EmailDns',
+        integer         => 'Dancer2::Plugin::FormValidator::Validator::Integer',
+        length_max      => 'Dancer2::Plugin::FormValidator::Validator::LengthMax',
+        length_min      => 'Dancer2::Plugin::FormValidator::Validator::LengthMin',
+        max             => 'Dancer2::Plugin::FormValidator::Validator::Max',
+        min             => 'Dancer2::Plugin::FormValidator::Validator::Min',
+        numeric         => 'Dancer2::Plugin::FormValidator::Validator::Numeric',
+        required        => 'Dancer2::Plugin::FormValidator::Validator::Required',
+        same            => 'Dancer2::Plugin::FormValidator::Validator::Same',
     };
 }
 
